@@ -1,8 +1,19 @@
 package CIF::Client::Plugin::Iptables;
+use CIF::Client::Support qw(confor);
 
+sub type { return 'output'; }
 sub write_out {
     my $self = shift;
-    my @array = @_;
+    my $config = shift;
+    my $feed = shift;
+    my @array = @{$feed->{'feed'}->{'entry'}};
+
+    my @config_search_path = ( $feed->{'query'}, 'client' );
+
+	# fyi
+	#   my $cfg_csv_noseparator = confor($config, \@config_search_path, 'csv_noseparator', undef);
+
+        
     my $text = "iptables -N CIF_IN\n";
     $text .= "iptables -F CIF_IN\n";
     $text .= "iptables -N CIF_OUT\n";
