@@ -1,5 +1,6 @@
 package CIF::Client::Plugin::Raw;
 use base 'CIF::Client::Plugin::Output';
+use CIF::Client::Support qw(confor);
 
 require JSON;
 
@@ -8,6 +9,12 @@ sub write_out {
     my $config = shift;
     my $feed = shift;
     my $json;
+    
+    my @config_search_path = ( $feed->{'query'}, 'client' );
+
+	# fyi
+	#   my $cfg_csv_noseparator = confor($config, \@config_search_path, 'csv_noseparator', undef);
+        
     if(1 || $config->{'stream'}){
         my @array = @{$feed->{'feed'}->{'entry'}};
         return unless(keys(%{$array[0]}));
