@@ -1,5 +1,6 @@
 package CIF::Client::Plugin::Table;
 use base 'CIF::Client::Plugin::Output';
+use CIF::Client::Support qw(confor);
 
 use Text::Table;
 
@@ -12,9 +13,20 @@ sub write_out {
 
     my $query = $feed->{'query'};
     my $hash = $feed->{'feed'};
-    my $group_map = ($config->{'group_map'}) ? $hash->{'group_map'} : undef;
     my $feed_guid = $hash->{'guid'};
-
+    my $group_map = ($config->{'group_map'}) ? $hash->{'group_map'} : undef;
+    
+	# we will look for each variable in the [query] section
+	# if it isnt there, we will check the [client] section.
+	# if it's not there either, we'll use the default
+	
+	my @config_search_path = ( $feed->{'query'}, 'client' );
+    my $cfg_fields = confor($config, \@config_search_path, 'fields', undef);
+    my $cfg_display = confor($config, \@config_search_path, 'display', undef);
+    my $cfg_compress_address = confor($config, \@config_search_path, 'compress_address', undef);
+    my $cfg_description = confor($config, \@config_search_path, 'description', undef);
+    my $cfg_table_nowarning = confor($config, \@config_search_path, 'table_nowarning', undef);
+    
     my $created = $hash->{'created'} || $hash->{'detecttime'};
     my $feedid = $hash->{'id'};
     my @a = @{$hash->{'entry'}};
@@ -69,11 +81,13 @@ sub write_out {
             'alternativeid_restriction',
             'alternativeid',
         ));
-   }
-   if($config->{'fields'}){
-        @cols = @{$config->{'fields'}};
     }
-    if(my $c = $self->{'config'}->{'display'}){
+   
+    if($cfg_fields) {
+        @cols = @{$cfg_fields};
+    }
+    
+    if(my $c = $cfg_display) {
         @cols = @$c;
     }
 
@@ -89,10 +103,13 @@ sub write_out {
     }
     @a = reverse(@a) if($reverse);
     foreach my $r (@a){
-        if($r->{'address'} && $config->{'compress_address'} && length($r->{'address'}) > 32){
+        if($r->{'address'} && $cfg_compress_address && length($r->{'address'}) > 32){
             $r->{'address'} = substr($r->{'address'},0,31);
             $r->{'address'} .= '...';
         }
+        # strip out non-ascii (typically unicode) chars
+        # there are better ways to do this, but this works for now
+        $r->{'description'} =~ tr/\000-\177//cd;
         $table->load([ map { $r->{$_} } @cols]);
     }
     if($created){
@@ -107,15 +124,15 @@ sub write_out {
     if($feedid){
         $table = 'Feed Id: '.$feedid."\n".$table;
     }
-    if($config->{'description'}){
-        $table = 'Description: '.$config->{'description'}."\n".$table;
+    if($cfg_description){
+        $table = 'Description: '.$cfg_description."\n".$table;
     }
     if($feed_guid){
         $feed_guid = $group_map->{$feed_guid} if($group_map);
         $table = 'Feed Group ID: '.$feed_guid."\n".$table;
     }
     $table = "Query: ".$query."\n".$table;
-    unless($config->{'config'}->{'table_nowarning'}){
+    unless($cfg_table_nowarning){
         $table = 'WARNING: Turn off this warning by adding: \'table_nowarning = 1\' to your ~/.cif config'."\n\n".$table;
         $table = 'WARNING: This table output not to be used for parsing, see "-p plugins" (via cif -h)'."\n".$table;
     }
